@@ -122,11 +122,11 @@ func TestSHA1Encode_Command(t *testing.T) {
 		title       string
 	}{
 		alias:       []string{"sha1-sum"},
-		description: "Get the SHA1 checksum of your text",
-		filterValue: "SHA1 Sum (sha1)",
+		description: "Get the SHA-1 checksum of your text",
+		filterValue: "SHA-1 Sum (sha1)",
 		flags:       nil,
 		name:        "sha1",
-		title:       "SHA1 Sum (sha1)",
+		title:       "SHA-1 Sum (sha1)",
 	}
 	p := SHA1{}
 	if got := p.Alias(); !reflect.DeepEqual(got, test.alias) {
@@ -203,11 +203,11 @@ func TestSHA256Encode_Command(t *testing.T) {
 		title       string
 	}{
 		alias:       []string{"sha256-sum"},
-		description: "Get the SHA256 checksum of your text",
-		filterValue: "SHA256 Sum (sha256)",
+		description: "Get the SHA-256 checksum of your text",
+		filterValue: "SHA-256 Sum (sha256)",
 		flags:       nil,
 		name:        "sha256",
-		title:       "SHA256 Sum (sha256)",
+		title:       "SHA-256 Sum (sha256)",
 	}
 	p := SHA256{}
 	if got := p.Alias(); !reflect.DeepEqual(got, test.alias) {
@@ -284,11 +284,11 @@ func TestSHA224Encode_Command(t *testing.T) {
 		title       string
 	}{
 		alias:       []string{"sha224-sum"},
-		description: "Get the SHA224 checksum of your text",
-		filterValue: "sha224 Sum (sha224)",
+		description: "Get the SHA-224 checksum of your text",
+		filterValue: "SHA-224 Sum (sha224)",
 		flags:       nil,
 		name:        "sha224",
-		title:       "sha224 Sum (sha224)",
+		title:       "SHA-224 Sum (sha224)",
 	}
 	p := SHA224{}
 	if got := p.Alias(); !reflect.DeepEqual(got, test.alias) {
@@ -365,11 +365,11 @@ func TestSHA384Encode_Command(t *testing.T) {
 		title       string
 	}{
 		alias:       []string{"sha384-sum"},
-		description: "Get the SHA384 checksum of your text",
-		filterValue: "sha384 Sum (sha384)",
+		description: "Get the SHA-384 checksum of your text",
+		filterValue: "SHA-384 Sum (sha384)",
 		flags:       nil,
 		name:        "sha384",
-		title:       "sha384 Sum (sha384)",
+		title:       "SHA-384 Sum (sha384)",
 	}
 	p := SHA384{}
 	if got := p.Alias(); !reflect.DeepEqual(got, test.alias) {
@@ -446,11 +446,11 @@ func TestSHA512Encode_Command(t *testing.T) {
 		title       string
 	}{
 		alias:       []string{"sha512-sum"},
-		description: "Get the SHA512 checksum of your text",
-		filterValue: "SHA512 Sum (sha512)",
+		description: "Get the SHA-512 checksum of your text",
+		filterValue: "SHA-512 Sum (sha512)",
 		flags:       nil,
 		name:        "sha512",
-		title:       "SHA512 Sum (sha512)",
+		title:       "SHA-512 Sum (sha512)",
 	}
 	p := SHA512{}
 	if got := p.Alias(); !reflect.DeepEqual(got, test.alias) {
@@ -527,8 +527,8 @@ func TestBcrypt_Command(t *testing.T) {
 		title       string
 	}{
 		alias:       []string{"bcrypt-hash"},
-		description: "Get the Bcrypt hash of your text",
-		filterValue: "Bcrypt Hash (bcrypt)",
+		description: "Get the bcrypt hash of your text",
+		filterValue: "bcrypt Hash (bcrypt)",
 		flags: []Flag{
 			{
 				Name:  "number-of-rounds",
@@ -539,7 +539,7 @@ func TestBcrypt_Command(t *testing.T) {
 			},
 		},
 		name:  "bcrypt",
-		title: "Bcrypt Hash (bcrypt)",
+		title: "bcrypt Hash (bcrypt)",
 	}
 	p := Bcrypt{}
 	if got := p.Alias(); !reflect.DeepEqual(got, test.alias) {
